# src/tessif/__init__.py
"""Tessif - Transforming Energy Supply System (M)odellIng Framework."""
from importlib.metadata import version

__version__ = version(__name__)
